@@ -1,4 +1,5 @@
 use crate::display_node::DisplayNode;
+use crate::node::FileTime;
 
 use ansi_term::Colour::Red;
 use lscolors::{LsColors, Style};
@@ -7,6 +8,7 @@ use unicode_width::UnicodeWidthStr;
 
 use stfu8::encode_u8;
 
+use chrono::{DateTime, Local, TimeZone, Utc};
 use std::cmp::max;
 use std::cmp::min;
 use std::fs;
@@ -14,14 +16,16 @@ use std::iter::repeat;
 use std::path::Path;
 use thousands::Separable;
 
-pub static UNITS: [char; 4] = ['T', 'G', 'M', 'K'];
+pub static UNITS: [char; 5] = ['P', 'T', 'G', 'M', 'K'];
 static BLOCKS: [char; 5] = ['█', '▓', '▒', '░', ' '];
+const FILETIME_SHOW_LENGTH: usize = 19;
 
 pub struct InitialDisplayData {
     pub short_paths: bool,
     pub is_reversed: bool,
     pub colors_on: bool,
     pub by_filecount: bool,
+    pub by_filetime: Option<FileTime>,
     pub is_screen_reader: bool,
     pub output_format: String,
     pub bars_on_right: bool,
@@ -130,17 +134,11 @@ pub fn draw_it(
     root_node: &DisplayNode,
     skip_total: bool,
 ) {
-    let biggest = match skip_total {
-        false => root_node,
-        true => root_node
-            .get_children_from_node(false)
-            .next()
-            .unwrap_or(root_node),
-    };
-
     let num_chars_needed_on_left_most = if idd.by_filecount {
-        let max_size = biggest.size;
+        let max_size = root_node.size;
         max_size.separate_with_commas().chars().count()
+    } else if idd.by_filetime.is_some() {
+        FILETIME_SHOW_LENGTH
     } else {
         find_biggest_size_str(root_node, &idd.output_format)
     };
@@ -166,7 +164,7 @@ pub fn draw_it(
     let display_data = DisplayData {
         initial: idd,
         num_chars_needed_on_left_most,
-        base_size: biggest.size,
+        base_size: root_node.size,
         longest_string_length,
         ls_colors: LsColors::from_env().unwrap_or_default(),
     };
@@ -275,7 +273,7 @@ fn clean_indentation_string(s: &str) -> String {
     is
 }
 
-fn get_printable_name<P: AsRef<Path>>(dir_name: &P, short_paths: bool) -> String {
+pub fn get_printable_name<P: AsRef<Path>>(dir_name: &P, short_paths: bool) -> String {
     let dir_name = dir_name.as_ref();
     let printable_name = {
         if short_paths {
@@ -342,6 +340,8 @@ pub fn format_string(
     if display_data.initial.is_screen_reader {
         // if screen_reader then bars is 'depth'
         format!("{pretty_name} {bars} {pretty_size}{percent}")
+    } else if display_data.initial.by_filetime.is_some() {
+        format!("{pretty_size} {indent}{pretty_name}")
     } else {
         format!("{pretty_size} {indent} {pretty_name}{percent}")
     }
@@ -376,6 +376,8 @@ fn get_name_percent(
 fn get_pretty_size(node: &DisplayNode, is_biggest: bool, display_data: &DisplayData) -> String {
     let output = if display_data.initial.by_filecount {
         node.size.separate_with_commas()
+    } else if display_data.initial.by_filetime.is_some() {
+        get_pretty_file_modified_time(node.size as i64)
     } else {
         human_readable_number(node.size, &display_data.initial.output_format)
     };
@@ -389,6 +391,14 @@ fn get_pretty_size(node: &DisplayNode, is_biggest: bool, display_data: &DisplayD
     }
 }
 
+fn get_pretty_file_modified_time(timestamp: i64) -> String {
+    let datetime: DateTime<Utc> = Utc.timestamp_opt(timestamp, 0).unwrap();
+
+    let local_datetime = datetime.with_timezone(&Local);
+
+    local_datetime.format("%Y-%m-%dT%H:%M:%S").to_string()
+}
+
 fn get_pretty_name(
     node: &DisplayNode,
     name_and_padding: String,
@@ -411,11 +421,14 @@ fn get_pretty_name(
 
 // If we are working with SI units or not
 pub fn get_type_of_thousand(output_str: &str) -> u64 {
-    let is_si = output_str.contains('i'); // si, KiB, MiB, etc
-    if is_si {
-        1000
-    } else {
+    if output_str.is_empty() {
         1024
+    } else if output_str == "si" {
+        1000
+    } else if output_str.contains('i') || output_str.len() == 1 {
+        1024
+    } else {
+        1000
     }
 }
 
@@ -466,6 +479,7 @@ mod tests {
             is_reversed: false,
             colors_on: false,
             by_filecount: false,
+            by_filetime: None,
             is_screen_reader: false,
             output_format: "".into(),
             bars_on_right: false,
@@ -544,6 +558,14 @@ mod tests {
         assert_eq!(human_readable_number(1024 * 1024 * 1024 - 1, ""), "1023M");
         assert_eq!(human_readable_number(1024 * 1024 * 1024 * 20, ""), "20G");
         assert_eq!(human_readable_number(1024 * 1024 * 1024 * 1024, ""), "1.0T");
+        assert_eq!(
+            human_readable_number(1024 * 1024 * 1024 * 1024 * 234, ""),
+            "234T"
+        );
+        assert_eq!(
+            human_readable_number(1024 * 1024 * 1024 * 1024 * 1024, ""),
+            "1.0P"
+        );
     }
 
     #[test]
@@ -552,23 +574,25 @@ mod tests {
         assert_eq!(human_readable_number(1024 * 100, "si"), "102K");
     }
 
+    // Refer to https://en.wikipedia.org/wiki/Byte#Multiple-byte_units
     #[test]
     fn test_human_readable_number_kb() {
         let hrn = human_readable_number;
         assert_eq!(hrn(1023, "b"), "1023B");
         assert_eq!(hrn(1000 * 1000, "bytes"), "1000000B");
-        assert_eq!(hrn(1023, "kb"), "0K");
-        assert_eq!(hrn(1023, "kib"), "1K");
-        assert_eq!(hrn(1024, "kb"), "1K");
-        assert_eq!(hrn(1024 * 512, "kb"), "512K");
-        assert_eq!(hrn(1024 * 1024, "kb"), "1024K");
-        assert_eq!(hrn(1024 * 1000 * 1000 * 20, "kb"), "20000000K");
-        assert_eq!(hrn(1024 * 1024 * 1000 * 20, "mb"), "20000M");
-        assert_eq!(hrn(1024 * 1024 * 1024 * 20, "gb"), "20G");
+        assert_eq!(hrn(1023, "kb"), "1K");
+        assert_eq!(hrn(1023, "k"), "0K");
+        assert_eq!(hrn(1023, "kib"), "0K");
+        assert_eq!(hrn(1024, "kib"), "1K");
+        assert_eq!(hrn(1024 * 512, "kib"), "512K");
+        assert_eq!(hrn(1024 * 1024, "kib"), "1024K");
+        assert_eq!(hrn(1024 * 1000 * 1000 * 20, "kib"), "20000000K");
+        assert_eq!(hrn(1024 * 1024 * 1000 * 20, "mib"), "20000M");
+        assert_eq!(hrn(1024 * 1024 * 1024 * 20, "gib"), "20G");
     }
 
     #[cfg(test)]
-    fn build_draw_data<'a>(disp: &'a DisplayData, size: u32) -> (DrawData<'a>, DisplayNode) {
+    fn build_draw_data(disp: &DisplayData, size: u32) -> (DrawData<'_>, DisplayNode) {
         let n = DisplayNode {
             name: PathBuf::from("/short"),
             size: 2_u64.pow(size),
@@ -620,4 +644,37 @@ mod tests {
         let bar = dd.generate_bar(&n, 5);
         assert_eq!(bar, "████▓▓▓▓▓▓▓▓▓");
     }
+
+    #[test]
+    fn test_get_pretty_file_modified_time() {
+        // Create a timestamp for 2023-07-12 00:00:00 in local time
+        let local_dt = Local.with_ymd_and_hms(2023, 7, 12, 0, 0, 0).unwrap();
+        let timestamp = local_dt.timestamp();
+
+        // Format expected output
+        let expected_output = local_dt.format("%Y-%m-%dT%H:%M:%S").to_string();
+
+        assert_eq!(get_pretty_file_modified_time(timestamp), expected_output);
+
+        // Test another timestamp
+        let local_dt = Local.with_ymd_and_hms(2020, 1, 1, 12, 0, 0).unwrap();
+        let timestamp = local_dt.timestamp();
+        let expected_output = local_dt.format("%Y-%m-%dT%H:%M:%S").to_string();
+
+        assert_eq!(get_pretty_file_modified_time(timestamp), expected_output);
+
+        // Test timestamp for epoch start (1970-01-01T00:00:00)
+        let local_dt = Local.with_ymd_and_hms(1970, 1, 1, 0, 0, 0).unwrap();
+        let timestamp = local_dt.timestamp();
+        let expected_output = local_dt.format("%Y-%m-%dT%H:%M:%S").to_string();
+
+        assert_eq!(get_pretty_file_modified_time(timestamp), expected_output);
+
+        // Test a future timestamp
+        let local_dt = Local.with_ymd_and_hms(2030, 12, 25, 6, 30, 0).unwrap();
+        let timestamp = local_dt.timestamp();
+        let expected_output = local_dt.format("%Y-%m-%dT%H:%M:%S").to_string();
+
+        assert_eq!(get_pretty_file_modified_time(timestamp), expected_output);
+    }
 }
